@@ -19,9 +19,9 @@
 
 #include <qtest.h>
 
-#include "kimap2test/fakeserver.h"
-#include "kimap2/session.h"
-#include "kimap2/listjob.h"
+#include "kimaptest/fakeserver.h"
+#include "kimap/session.h"
+#include "kimap/listjob.h"
 
 #include <QtTest>
 
@@ -33,30 +33,30 @@ private Q_SLOTS:
 
     void testLoadScenario()
     {
-        KIMAP2::MailBoxDescriptor descriptor;
-        QList<KIMAP2::MailBoxDescriptor> listresult;
+        KIMAP::MailBoxDescriptor descriptor;
+        QList<KIMAP::MailBoxDescriptor> listresult;
 
         descriptor.separator = QLatin1Char('/');
-        descriptor.name = QStringLiteral("INBOX");
+        descriptor.name = QLatin1String("INBOX");
         listresult << descriptor;
         descriptor.separator = QLatin1Char('/');
         descriptor.name = QString::fromUtf8("INBOX/ä ö ü @ €");
         listresult << descriptor;
         descriptor.separator = QLatin1Char('/');
-        descriptor.name = QStringLiteral("INBOX/lost+found");
+        descriptor.name = QLatin1String("INBOX/lost+found");
         listresult << descriptor;
         descriptor.separator = QLatin1Char('/');
-        descriptor.name = QStringLiteral("INBOX/lost+found/Calendar Public-20080128");
+        descriptor.name = QLatin1String("INBOX/lost+found/Calendar Public-20080128");
         listresult << descriptor;
 
         FakeServer fakeServer;
-        fakeServer.addScenarioFromFile(QStringLiteral(TEST_DATA) + QStringLiteral("/fakeserverscenario.log"));
+        fakeServer.addScenarioFromFile(QString(QLatin1String(TEST_DATA) + QLatin1String("/fakeserverscenario.log")));
         fakeServer.startAndWait();
 
-        KIMAP2::Session session(QStringLiteral("127.0.0.1"), 5989);
+        KIMAP::Session session(QLatin1String("127.0.0.1"), 5989);
 
-        KIMAP2::ListJob *job = new KIMAP2::ListJob(&session);
-        job->setOption(KIMAP2::ListJob::IncludeUnsubscribed);
+        KIMAP::ListJob *job = new KIMAP::ListJob(&session);
+        job->setIncludeUnsubscribed(true);
         QVERIFY(job->exec());
 
         fakeServer.quit();
