@@ -19,26 +19,26 @@
 
 #include <qtest.h>
 
-#include "kimap2test/fakeserver.h"
-#include "kimap2/session.h"
-#include "kimap2/selectjob.h"
-#include "kimap2/idlejob.h"
+#include "kimaptest/fakeserver.h"
+#include "kimap/session.h"
+#include "kimap/selectjob.h"
+#include "kimap/idlejob.h"
 
 #include <QtTest>
 
 Q_DECLARE_METATYPE(QList<int>)
 Q_DECLARE_METATYPE(QList<qint64>)
-Q_DECLARE_METATYPE(KIMAP2::IdleJob *)
+Q_DECLARE_METATYPE(KIMAP::IdleJob *)
 
 class IdleJobTest: public QObject
 {
     Q_OBJECT
 
 public:
-    explicit IdleJobTest(QObject *parent = nullptr)
+    explicit IdleJobTest(QObject *parent = 0)
         : QObject(parent)
     {
-        qRegisterMetaType<KIMAP2::IdleJob *>();
+        qRegisterMetaType<KIMAP::IdleJob *>();
     }
 
 private Q_SLOTS:
@@ -68,7 +68,7 @@ private Q_SLOTS:
                  << "S: * 2 EXISTS"
                  << "S: A000002 OK done idling";
 
-        expectedMailBox = QStringLiteral("INBOX/Foo");
+        expectedMailBox = QLatin1String("INBOX/Foo");
 
         expectedMessageCounts.clear();
         expectedRecentCounts.clear();
@@ -88,7 +88,7 @@ private Q_SLOTS:
                  << "S: * 1 RECENT"
                  << "S: A000002 OK done idling";
 
-        expectedMailBox = QStringLiteral("INBOX/Foo");
+        expectedMailBox = QLatin1String("INBOX/Foo");
 
         expectedMessageCounts.clear();
         expectedRecentCounts.clear();
@@ -108,7 +108,7 @@ private Q_SLOTS:
                  << "S: * 2 EXISTS"
                  << "S: A000002 OK done idling";
 
-        expectedMailBox = QStringLiteral("INBOX/Foo");
+        expectedMailBox = QLatin1String("INBOX/Foo");
 
         expectedMessageCounts.clear();
         expectedRecentCounts.clear();
@@ -129,7 +129,7 @@ private Q_SLOTS:
                  << "S: * 1 RECENT"
                  << "S: A000002 OK done idling";
 
-        expectedMailBox = QStringLiteral("INBOX/Foo");
+        expectedMailBox = QLatin1String("INBOX/Foo");
 
         expectedMessageCounts.clear();
         expectedRecentCounts.clear();
@@ -150,7 +150,7 @@ private Q_SLOTS:
                  << "S: * 1 RECENT"
                  << "S: A000002 OK done idling";
 
-        expectedMailBox = QStringLiteral("INBOX/Foo");
+        expectedMailBox = QLatin1String("INBOX/Foo");
 
         expectedMessageCounts.clear();
         expectedRecentCounts.clear();
@@ -171,7 +171,7 @@ private Q_SLOTS:
                  << "S: * 2 FETCH (FLAGS (\\Seen))"
                  << "S: A000002 OK done idling";
 
-        expectedMailBox = QStringLiteral("INBOX/Foo");
+        expectedMailBox = QLatin1String("INBOX/Foo");
 
         expectedMessageCounts.clear();
         expectedRecentCounts.clear();
@@ -194,16 +194,16 @@ private Q_SLOTS:
         fakeServer.setScenario(scenario);
         fakeServer.startAndWait();
 
-        KIMAP2::Session session(QStringLiteral("127.0.0.1"), 5989);
+        KIMAP::Session session(QLatin1String("127.0.0.1"), 5989);
 
-        KIMAP2::SelectJob *select = new KIMAP2::SelectJob(&session);
+        KIMAP::SelectJob *select = new KIMAP::SelectJob(&session);
         select->setMailBox(expectedMailBox);
         QVERIFY(select->exec());
 
-        KIMAP2::IdleJob *idle = new KIMAP2::IdleJob(&session);
+        KIMAP::IdleJob *idle = new KIMAP::IdleJob(&session);
 
-        QSignalSpy statsSpy(idle, SIGNAL(mailBoxStats(KIMAP2::IdleJob*,QString,int,int)));
-        QSignalSpy flagsSpy(idle, SIGNAL(mailBoxMessageFlagsChanged(KIMAP2::IdleJob*,qint64)));
+        QSignalSpy statsSpy(idle, SIGNAL(mailBoxStats(KIMAP::IdleJob*,QString,int,int)));
+        QSignalSpy flagsSpy(idle, SIGNAL(mailBoxMessageFlagsChanged(KIMAP::IdleJob*,qint64)));
 
         bool result = idle->exec();
 
@@ -212,7 +212,7 @@ private Q_SLOTS:
             QCOMPARE(flagsSpy.count(), expectedFlagsNotifications.size());
 
             for (int i = 0 ; i < statsSpy.count(); i++) {
-                const KIMAP2::IdleJob *job = statsSpy.at(i).at(0).value<KIMAP2::IdleJob *>();
+                const KIMAP::IdleJob *job = statsSpy.at(i).at(0).value<KIMAP::IdleJob *>();
                 const QString mailBox = statsSpy.at(i).at(1).toString();
                 const int messageCount = statsSpy.at(i).at(2).toInt();
                 const int recentCount = statsSpy.at(i).at(3).toInt();
@@ -224,7 +224,7 @@ private Q_SLOTS:
             }
 
             for (int i = 0; i < flagsSpy.count(); i++) {
-                const KIMAP2::IdleJob *job = flagsSpy.at(i).at(0).value<KIMAP2::IdleJob *>();
+                const KIMAP::IdleJob *job = flagsSpy.at(i).at(0).value<KIMAP::IdleJob *>();
                 const qint64 uid = flagsSpy.at(i).at(1).toLongLong();
 
                 QCOMPARE(job, idle);
@@ -271,14 +271,14 @@ private Q_SLOTS:
         fakeServer.setScenario(scenario);
         fakeServer.startAndWait();
 
-        KIMAP2::Session session(QStringLiteral("127.0.0.1"), 5989);
+        KIMAP::Session session(QLatin1String("127.0.0.1"), 5989);
         const int originalTimeout = session.timeout();
 
-        KIMAP2::SelectJob *select = new KIMAP2::SelectJob(&session);
-        select->setMailBox(QStringLiteral("INBOX"));
+        KIMAP::SelectJob *select = new KIMAP::SelectJob(&session);
+        select->setMailBox(QLatin1String("INBOX"));
         QVERIFY(select->exec());
 
-        KIMAP2::IdleJob *idle = new KIMAP2::IdleJob(&session);
+        KIMAP::IdleJob *idle = new KIMAP::IdleJob(&session);
         idle->exec();
 
         QCOMPARE(session.timeout(), originalTimeout);
