@@ -21,9 +21,9 @@
 
 #include <qtest.h>
 
-#include "kimap2test/fakeserver.h"
-#include "kimap2/session.h"
-#include "kimap2/renamejob.h"
+#include "kimaptest/fakeserver.h"
+#include "kimap/session.h"
+#include "kimap/renamejob.h"
 
 #include <QtTest>
 
@@ -68,9 +68,9 @@ private Q_SLOTS:
         fakeServer.setScenario(scenario);
         fakeServer.startAndWait();
 
-        KIMAP2::Session session(QStringLiteral("127.0.0.1"), 5989);
+        KIMAP::Session session(QLatin1String("127.0.0.1"), 5989);
 
-        KIMAP2::RenameJob *job = new KIMAP2::RenameJob(&session);
+        KIMAP::RenameJob *job = new KIMAP::RenameJob(&session);
         job->setSourceMailBox(mailbox);
         job->setDestinationMailBox(newname);
         bool result = job->exec();
