@@ -19,14 +19,16 @@
 
 #include "listjob.h"
 
+#include <boost/bind.hpp>
+#include <QtCore/QTimer>
+#include <KLocalizedString>
+
 #include "job_p.h"
 #include "message_p.h"
 #include "rfccodecs.h"
 #include "session_p.h"
 
-static const int _kimap_mailBoxDescriptorId = qRegisterMetaType<KIMAP2::MailBoxDescriptor>();
-
-namespace KIMAP2
+namespace KIMAP
 {
 class ListJobPrivate : public JobPrivate
 {
@@ -34,25 +36,60 @@ public:
     ListJobPrivate(ListJob *job, Session *session, const QString &name) : JobPrivate(session, name), q(job), option(ListJob::NoOption) { }
     ~ListJobPrivate() { }
 
+    void emitPendings()
+    {
+        if (pendingDescriptors.isEmpty()) {
+            return;
+        }
+
+        emit q->mailBoxesReceived(pendingDescriptors, pendingFlags);
+
+        pendingDescriptors.clear();
+        pendingFlags.clear();
+    }
+
     ListJob *const q;
 
     ListJob::Option option;
     QList<MailBoxDescriptor> namespaces;
     QByteArray command;
+
+    QTimer emitPendingsTimer;
+    QList<MailBoxDescriptor> pendingDescriptors;
+    QList< QList<QByteArray> > pendingFlags;
 };
 }
 
-using namespace KIMAP2;
+using namespace KIMAP;
 
 ListJob::ListJob(Session *session)
-    : Job(*new ListJobPrivate(this, session, "List"))
+    : Job(*new ListJobPrivate(this, session, i18n("List")))
 {
+    Q_D(ListJob);
+    connect(&d->emitPendingsTimer, SIGNAL(timeout()),
+            this, SLOT(emitPendings()));
 }
 
 ListJob::~ListJob()
 {
 }
 
+void ListJob::setIncludeUnsubscribed(bool include)
+{
+    Q_D(ListJob);
+    if (include) {
+        d->option = ListJob::IncludeUnsubscribed;
+    } else {
+        d->option = ListJob::NoOption;
+    }
+}
+
+bool ListJob::isIncludeUnsubscribed() const
+{
+    Q_D(const ListJob);
+    return (d->option == ListJob::IncludeUnsubscribed);
+}
+
 void ListJob::setOption(Option option)
 {
     Q_D(ListJob);
@@ -77,6 +114,16 @@ QList<MailBoxDescriptor> ListJob::queriedNamespaces() const
     return d->namespaces;
 }
 
+QList<MailBoxDescriptor> ListJob::mailBoxes() const
+{
+    return QList<MailBoxDescriptor>();
+}
+
+QMap< MailBoxDescriptor, QList<QByteArray> > ListJob::flags() const
+{
+    return QMap< MailBoxDescriptor, QList<QByteArray> >();
+}
+
 void ListJob::doStart()
 {
     Q_D(ListJob);
@@ -94,8 +141,10 @@ void ListJob::doStart()
         d->command = "LSUB";
     }
 
+    d->emitPendingsTimer.start(100);
+
     if (d->namespaces.isEmpty()) {
-        d->sendCommand(d->command, "\"\" *");
+        d->tags << d->sessionInternal()->sendCommand(d->command, "\"\" *");
     } else {
         foreach (const MailBoxDescriptor &descriptor, d->namespaces) {
             QString parameters = QStringLiteral("\"\" \"%1\"");
@@ -103,11 +152,11 @@ void ListJob::doStart()
             if (descriptor.name.endsWith(descriptor.separator)) {
                 QString name = encodeImapFolderName(descriptor.name);
                 name.chop(1);
-                d->sendCommand(d->command,
+                d->tags << d->sessionInternal()->sendCommand(d->command,
                         parameters.arg(name).toUtf8());
             }
 
-            d->sendCommand(d->command,
+            d->tags << d->sessionInternal()->sendCommand(d->command,
                     parameters.arg(descriptor.name + QLatin1Char('*')).toUtf8());
         }
     }
@@ -117,6 +166,15 @@ void ListJob::handleResponse(const Message &response)
 {
     Q_D(ListJob);
 
+    // We can predict it'll be handled by handleErrorReplies() so stop
+    // the timer now so that result() will really be the last emitted signal.
+    if (!response.content.isEmpty() &&
+            d->tags.size() == 1 &&
+            d->tags.contains(response.content.first().toString())) {
+        d->emitPendingsTimer.stop();
+        d->emitPendings();
+    }
+
     if (handleErrorReplies(response) == NotHandled) {
         if (response.content.size() >= 5 && response.content[1].toString() == d->command) {
             QList<QByteArray> flags = response.content[2].toList();
@@ -144,19 +202,20 @@ void ListJob::handleResponse(const Message &response)
             mailBoxDescriptor.name = QString::fromUtf8(fullName);
             convertInboxName(mailBoxDescriptor);
 
-            emit resultReceived(mailBoxDescriptor, flags);
+            d->pendingDescriptors << mailBoxDescriptor;
+            d->pendingFlags << flags;
         }
     }
 }
 
-void ListJob::convertInboxName(KIMAP2::MailBoxDescriptor &descriptor)
+void ListJob::convertInboxName(KIMAP::MailBoxDescriptor &descriptor)
 {
     //Inbox must be case sensitive, according to the RFC, so make it always uppercase
     QStringList pathParts = descriptor.name.split(descriptor.separator);
     if (!pathParts.isEmpty() &&
             pathParts[0].compare(QLatin1String("INBOX"), Qt::CaseInsensitive) == 0) {
         pathParts.removeAt(0);
-        descriptor.name = QStringLiteral("INBOX");
+        descriptor.name = QLatin1String("INBOX");
         if (!pathParts.isEmpty()) {
             descriptor.name += descriptor.separator + pathParts.join(descriptor.separator);
         }
