@@ -19,6 +19,7 @@
 
 #include "searchjob.h"
 
+#include <KLocalizedString>
 #include "kimap_debug.h"
 
 #include <QtCore/QDate>
@@ -28,13 +29,13 @@
 #include "session_p.h"
 #include "imapset.h"
 
-namespace KIMAP2
+namespace KIMAP
 {
 
 class Term::Private
 {
 public:
-    Private(): isFuzzy(false), isNegated(false), isNull(false) {}
+    Private(): isFuzzy(false), isNegated(false), isNull(false) {};
     QByteArray command;
     bool isFuzzy;
     bool isNegated;
@@ -52,7 +53,7 @@ Term::Term(Term::Relation relation, const QVector<Term> &subterms)
 {
     if (subterms.size() >= 2) {
         d->command += "(";
-        if (relation == KIMAP2::Term::Or) {
+        if (relation == KIMAP::Term::Or) {
             d->command += "OR ";
             d->command += subterms.at(0).serialize() + ' ';
             if (subterms.size() >= 3) {
@@ -153,12 +154,27 @@ Term::Term(Term::BooleanSearchKey key)
     }
 }
 
-static QByteArray monthName(int month)
+QMap<int, QByteArray> initializeMonths()
 {
-    static const char* names[12] = {"Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep", "Oct", "Nov", "Dec"};
-    return (month >= 1 && month <= 12) ? QByteArray(names[month - 1]) : QByteArray();
+    QMap<int, QByteArray> months;
+    //don't use QDate::shortMonthName(), it returns a localized month name
+    months[1] = "Jan";
+    months[2] = "Feb";
+    months[3] = "Mar";
+    months[4] = "Apr";
+    months[5] = "May";
+    months[6] = "Jun";
+    months[7] = "Jul";
+    months[8] = "Aug";
+    months[9] = "Sep";
+    months[10] = "Oct";
+    months[11] = "Nov";
+    months[12] = "Dec";
+    return months;
 }
 
+static QMap<int, QByteArray> months = initializeMonths();
+
 Term::Term(Term::DateSearchKey key, const QDate &date)
     :  d(new Term::Private)
 {
@@ -184,7 +200,7 @@ Term::Term(Term::DateSearchKey key, const QDate &date)
     }
     d->command += " \"";
     d->command += QByteArray::number(date.day()) + '-';
-    d->command += monthName(date.month()) + '-';
+    d->command += months[date.month()] + '-';
     d->command += QByteArray::number(date.year());
     d->command += '\"';
 }
@@ -330,17 +346,17 @@ public:
     QMap<int, QByteArray> months;
     SearchJob::SearchLogic logic;
     QList<QByteArray> contents;
-    QVector<qint64> results;
+    QList<qint64> results;
     uint nextContent;
     bool uidBased;
     Term term;
 };
 }
 
-using namespace KIMAP2;
+using namespace KIMAP;
 
 SearchJob::SearchJob(Session *session)
-    : Job(*new SearchJobPrivate(session, "Search"))
+    : Job(*new SearchJobPrivate(session, i18nc("Name of the search job", "Search")))
 {
 }
 
@@ -403,7 +419,7 @@ void SearchJob::doStart()
         command = "UID " + command;
     }
 
-    d->sendCommand(command, searchKey);
+    d->tags << d->sessionInternal()->sendCommand(command, searchKey);
 }
 
 void SearchJob::handleResponse(const Message &response)
@@ -411,14 +427,14 @@ void SearchJob::handleResponse(const Message &response)
     Q_D(SearchJob);
 
     if (handleErrorReplies(response) == NotHandled) {
-        if (response.content.size() >= 1 && response.content[0].toString() == "+") {
+        if (response.content[0].toString() == "+") {
             if (d->term.isNull()) {
                 d->sessionInternal()->sendData(d->contents[d->nextContent]);
             } else {
-                qCWarning(KIMAP2_LOG) << "The term API only supports inline strings.";
+                qCWarning(KIMAP_LOG) << "The term API only supports inline strings.";
             }
             d->nextContent++;
-        } else if (response.content.size() >= 2 && response.content[1].toString() == "SEARCH") {
+        } else if (response.content[1].toString() == "SEARCH") {
             for (int i = 2; i < response.content.size(); i++) {
                 d->results.append(response.content[i].toString().toInt());
             }
@@ -438,6 +454,110 @@ QByteArray SearchJob::charset() const
     return d->charset;
 }
 
+void SearchJob::setSearchLogic(SearchLogic logic)
+{
+    Q_D(SearchJob);
+    d->logic = logic;
+}
+
+void SearchJob::addSearchCriteria(SearchCriteria criteria)
+{
+    Q_D(SearchJob);
+
+    switch (criteria) {
+    case All:
+    case Answered:
+    case Deleted:
+    case Draft:
+    case Flagged:
+    case New:
+    case Old:
+    case Recent:
+    case Seen:
+    case Unanswered:
+    case Undeleted:
+    case Undraft:
+    case Unflagged:
+    case Unseen:
+        d->criterias.append(d->criteriaMap[criteria]);
+        break;
+    default:
+        //TODO Discuss if we keep error checking here, or accept anything, even if it is wrong
+        qCDebug(KIMAP_LOG) << "Criteria " << d->criteriaMap[criteria] << " needs an argument, but none was specified.";
+        break;
+    }
+}
+
+void SearchJob::addSearchCriteria(SearchCriteria criteria, int argument)
+{
+    Q_D(SearchJob);
+    switch (criteria) {
+    case Larger:
+    case Smaller:
+        d->criterias.append(d->criteriaMap[criteria] + ' ' + QByteArray::number(argument));
+        break;
+    default:
+        //TODO Discuss if we keep error checking here, or accept anything, even if it is wrong
+        qCDebug(KIMAP_LOG) << "Criteria " << d->criteriaMap[criteria] << " doesn't accept an integer as an argument.";
+        break;
+    }
+}
+
+void SearchJob::addSearchCriteria(SearchCriteria criteria, const QByteArray &argument)
+{
+    Q_D(SearchJob);
+    switch (criteria) {
+    case BCC:
+    case Body:
+    case CC:
+    case From:
+    case Subject:
+    case Text:
+    case To:
+        d->contents.append(argument);
+        d->criterias.append(d->criteriaMap[criteria] + " {" + QByteArray::number(argument.size()) + '}');
+        break;
+    case Keyword:
+    case Unkeyword:
+    case Header:
+    case Uid:
+        d->criterias.append(d->criteriaMap[criteria] + ' ' + argument);
+        break;
+    default:
+        //TODO Discuss if we keep error checking here, or accept anything, even if it is wrong
+        qCDebug(KIMAP_LOG) << "Criteria " << d->criteriaMap[criteria] << " doesn't accept any argument.";
+        break;
+    }
+}
+
+void SearchJob::addSearchCriteria(SearchCriteria criteria, const QDate &argument)
+{
+    Q_D(SearchJob);
+    switch (criteria) {
+    case Before:
+    case On:
+    case SentBefore:
+    case SentSince:
+    case Since: {
+        QByteArray date = QByteArray::number(argument.day()) + '-';
+        date += d->months[argument.month()] + '-';
+        date += QByteArray::number(argument.year());
+        d->criterias.append(d->criteriaMap[criteria] + " \"" + date + '\"');
+        break;
+    }
+    default:
+        //TODO Discuss if we keep error checking here, or accept anything, even if it is wrong
+        qCDebug(KIMAP_LOG) << "Criteria " << d->criteriaMap[criteria] << " doesn't accept a date as argument.";
+        break;
+    }
+}
+
+void SearchJob::addSearchCriteria(const QByteArray &searchCriteria)
+{
+    Q_D(SearchJob);
+    d->criterias.append(searchCriteria);
+}
+
 void SearchJob::setUidBased(bool uidBased)
 {
     Q_D(SearchJob);
@@ -450,8 +570,18 @@ bool SearchJob::isUidBased() const
     return d->uidBased;
 }
 
-QVector<qint64> SearchJob::results() const
+QList<qint64> SearchJob::results() const
 {
     Q_D(const SearchJob);
     return d->results;
 }
+
+QList<int> SearchJob::foundItems()
+{
+    Q_D(const SearchJob);
+
+    QList<int> results;
+    qCopy(d->results.begin(), d->results.end(), results.begin());
+
+    return results;
+}
