@@ -19,7 +19,10 @@
   * Boston, MA 02110-1301, USA.
   */
 
+#include <kcomponentdata.h>
+#include <k4aboutdata.h>
 #include <qdebug.h>
+#include <klocalizedstring.h>
 #include <qtcpsocket.h>
 #include <QCoreApplication>
 #include <qsignalspy.h>
@@ -42,6 +45,7 @@
 #include "unsubscribejob.h"
 #include "renamejob.h"
 #include "storejob.h"
+#include "sessionuiproxy.h"
 #include "setacljob.h"
 #include "getacljob.h"
 #include "deleteacljob.h"
@@ -50,7 +54,16 @@
 #include "setmetadatajob.h"
 #include "getmetadatajob.h"
 
-using namespace KIMAP2;
+using namespace KIMAP;
+
+class UiProxy: public SessionUiProxy
+{
+public:
+    bool ignoreSslError(const KSslErrorUiData &errorData)
+    {
+        return true;
+    }
+};
 
 void dumpContentHelper(KMime::Content *part, const QString &partId = QString())
 {
@@ -76,7 +89,7 @@ void dumpContentHelper(KMime::Content *part, const QString &partId = QString())
 void listFolders(Session *session, bool includeUnsubscribed = false, const QString &nameFilter = QLatin1String(""))
 {
     ListJob *list = new ListJob(session);
-    list->setOption(KIMAP2::ListJob::IncludeUnsubscribed);
+    list->setIncludeUnsubscribed(includeUnsubscribed);
     list->exec();
     Q_ASSERT_X(list->error() == 0, "ListJob", list->errorString().toLocal8Bit().constData());
     int count = list->mailBoxes().size();
@@ -93,25 +106,25 @@ void testMetaData(Session *session)
 {
     qDebug() << "TESTING: METADATA commands";
     CreateJob *create = new CreateJob(session);
-    create->setMailBox(QStringLiteral("INBOX/TestFolder"));
+    create->setMailBox(QLatin1String("INBOX/TestFolder"));
     create->exec();
 
     SetMetaDataJob *setmetadata = new SetMetaDataJob(session);
-    setmetadata->setMailBox(QStringLiteral("INBOX/TestFolder"));
+    setmetadata->setMailBox(QLatin1String("INBOX/TestFolder"));
     setmetadata->setServerCapability(SetMetaDataJob::Annotatemore);
     setmetadata->setEntry("/comment");
     setmetadata->addMetaData("value.priv", "My new comment");
     setmetadata->exec();
 
     setmetadata = new SetMetaDataJob(session);
-    setmetadata->setMailBox(QStringLiteral("INBOX/TestFolder"));
+    setmetadata->setMailBox(QLatin1String("INBOX/TestFolder"));
     setmetadata->setServerCapability(SetMetaDataJob::Annotatemore);
     setmetadata->setEntry("/check");
     setmetadata->addMetaData("value.priv", "true");
     setmetadata->exec();
 
     GetMetaDataJob *getmetadata = new GetMetaDataJob(session);
-    getmetadata->setMailBox(QStringLiteral("INBOX/TestFolder"));
+    getmetadata->setMailBox(QLatin1String("INBOX/TestFolder"));
     getmetadata->setServerCapability(SetMetaDataJob::Annotatemore);
     getmetadata->addEntry("/*", "value.priv");
     getmetadata->exec();
@@ -265,15 +278,15 @@ void testAppendAndStore(Session *session)
     Q_ASSERT(expectedFlags == resultingFlags);
 
     select = new SelectJob(session);
-    select->setMailBox(QStringLiteral("INBOX"));
+    select->setMailBox(QLatin1String("INBOX"));
     select->exec();
 
     //cleanup
     DeleteJob *deletejob = new DeleteJob(session);
-    deletejob->setMailBox(QStringLiteral("INBOX/TestFolder"));
+    deletejob->setMailBox(QLatin1String("INBOX/TestFolder"));
     deletejob->exec();
     deletejob = new DeleteJob(session);
-    deletejob->setMailBox(QStringLiteral("INBOX/RenamedTestFolder"));
+    deletejob->setMailBox(QLatin1String("INBOX/RenamedTestFolder"));
     deletejob->exec();
 }
 
@@ -365,7 +378,8 @@ void testDelete(Session *session)
 
 int main(int argc, char **argv)
 {
-    QCoreApplication::setApplicationName(QStringLiteral("TestImapServer"));
+    K4AboutData about("TestImapServer", 0, ki18n("TestImapServer"), "version");
+    KComponentData cData(&about);
 
     if (argc < 4) {
         qCritical() << "Not enough parameters, expecting: <server> <user> <password>";
@@ -385,11 +399,8 @@ int main(int argc, char **argv)
 
     QCoreApplication app(argc, argv);
     Session session(server, port);
-
-    QObject::connect(&session, &KIMAP2::Session::sslErrors, [&session](const QList<QSslError> &errors) {
-        qWarning() << "Got ssl error: " << errors;
-        session.ignoreErrors(errors);
-    });
+    UiProxy::Ptr proxy(new UiProxy());
+    session.setUiProxy(proxy);
 
     qDebug() << "Logging in...";
     LoginJob *login = new LoginJob(&session);
@@ -512,7 +523,7 @@ int main(int argc, char **argv)
     Q_ASSERT_X(fetch->error() == 0, "FetchJob", fetch->errorString().toLocal8Bit().constData());
     Q_ASSERT(session.state() == Session::Selected);
     MessagePtr message = fetch->messages()[1];
-    dumpContentHelper(message.data());
+    dumpContentHelper(message.get());
     qDebug();
 
     qDebug() << "Fetching first message second part headers:";
